@@ -22,7 +22,7 @@ class SparrowData:
     color: str = Color.SECONDARY
     body_text: str = ""
     """
-    def __init__(self, workspace="", username="", command="", channel="", title_text="", color=Color.SECONDARY, body_text=""):
+    def __init__(self, workspace="", username="", command="", channel="", title_text="", color="", body_text=""):
         self.workspace = workspace
         self.username = username
         self.command = command
